#!/bin/sh
# Run this to generate all the initial makefiles, etc.

set -e
srcdir=`dirname $0`
test -z "$srcdir" && srcdir=.

THEDIR=`pwd`
cd $srcdir

DIE=0

(autoconf --version) < /dev/null > /dev/null 2>&1 || {
    echo
    echo "You must have autoconf installed to compile virt-viewer."
    echo "Download the appropriate package for your distribution,"
    echo "or see http://www.gnu.org/software/autoconf"
    DIE=1
}

(automake --version) < /dev/null > /dev/null 2>&1 || {
    echo
    DIE=1
    echo "You must have automake installed to compile virt-viewer."
    echo "Download the appropriate package for your distribution,"
    echo "or see http://www.gnu.org/software/automake"
}

if test "$DIE" -eq 1; then
    exit 1
fi

EXTRA_ARGS=""
if test "x$1" = "x--system"; then
    shift
    prefix=/usr
    libdir=$prefix/lib
    sysconfdir=/etc
    localstatedir=/var
    if [ -d /usr/lib64 ]; then
        libdir=$prefix/lib64
    fi
    EXTRA_ARGS="--prefix=$prefix --sysconfdir=$sysconfdir --localstatedir=$localstatedir --libdir=$libdir"
    echo "Running ./configure with $EXTRA_ARGS $@"
else
    if test -z "$*" ; then
        echo "I am going to run ./configure with no arguments - if you wish "
        echo "to pass any to it, please specify them on the $0 command line."
    fi
fi

libtoolize --copy --force
intltoolize --force
aclocal -I m4
autoheader
automake --add-missing --copy
autoconf

cd $THEDIR

$srcdir/configure $EXTRA_ARGS "$@" && {
    echo
    echo "Now type 'make' to compile virt-viewer."
}
